!---------------------------------------------------------------------------------------
! FLEXINVERT : calcselector 
!---------------------------------------------------------------------------------------
!  Copyright 2013, Rona Thompson
!
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!---------------------------------------------------------------------------------------
!> Calculates the constraint selector matrix
!---------------------------------------------------------------------------------------

subroutine calcselector()

  use mod_var

  implicit none

  integer :: i,j

  ! find elements of state vector outside the constraint

  if (contype.eq.0) then
    write(logid,*) 'Constraining grid cells to ',ineq
    nineq=0
    do i=1,nvar
      if(x0(i).lt.ineq) then
        nineq=nineq+1
      endif
    end do
    write(logid, *) 'Number of values outside constraint:', nineq

    if(nineq.eq.0) then
      write(logid,*) 'No values violate the constraint'
      stop
    endif
  else
    write(logid,*) 'Constraining total global'
    nineq=nemsteps
  endif

  
  allocate(selmat(nineq,nvar))

  if (contype.eq.0) then ! define selector matrix if constraining grid cells
    allocate(ineqvec(nineq))
    ineqvec(:)=ineq*numscale/outheight ! Unit: kg/s*numscale/outheight
    selmat(:,:)=0
    
    j=0
    do i=1,nvar
      if(x0(i).lt.ineq) then
        j=j+1
        selmat(j,i)=1
        !print*, 'Select:', j, i
      endif
    end do
  else ! use summation matrix if constraining total global
       ! ineqvec is already defined in readinput.f90
    selmat(:,:)=0
    do i=1,nineq
      selmat(i,(i-1)*nbox+1:i*nbox)=area_box
    end do
  endif
end subroutine calcselector

