!---------------------------------------------------------------------------------------
! PREP_FLUXES: gridarea
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> gridarea
!!
!! Purpose:    Calculates the area of a grid cell.
!!
!! Interface:
!!
!!    Inputs
!!             ylat  -  latitude of grid centre
!!             dy    -  resolution in latitudinal direction
!!             dx    -  resolution in longitudinal direction
!!
!!    Outputs
!!             area  -  area of grid cell
!!
!---------------------------------------------------------------------------------------

subroutine gridarea(ylat,dy,dx,area)

  implicit none

  real, intent(in)  :: ylat,dy,dx
  real, intent(out) :: area

  real, parameter   :: pi=3.14159265, rearth=6.371e6, pih=pi/180.
  real              :: ylata, ylatp, ylatm 
  real              :: cosfact, cosfactp, cosfactm, hzone

  ylata=ylat
  ylatp=ylat+0.5*dy
  ylatm=ylat-0.5*dy
  if (ylatm.lt.0.and.ylatp.gt.0) then
    hzone = rearth*pih
  else
    cosfact=COS(ylata*pih)*rearth
    cosfactp=COS(ylatp*pih)*rearth
    cosfactm=COS(ylatm*pih)*rearth
    if(cosfactp.lt.cosfactm) then
      hzone=SQRT(rearth**2-cosfactp**2)-SQRT(rearth**2-cosfactm**2)
    else
      hzone=SQRT(rearth**2-cosfactm**2)-SQRT(rearth**2-cosfactp**2)
    endif
  endif
  area=2.*pi*rearth*hzone*dx/360.
       
end subroutine gridarea
